@@ -5,8 +5,8 @@ import os.path
 import traceback
 from watchdog.observers import Observer
 from maryjane.tags import TaskTag, SubprocessActionTag, TemplateTag, ObservableTaskTag,\
-    EvaluateTag, OptionsTag, WatcherTag, ImportTag
-from maryjane.helpers import get_source_dirs, has_file_overlap, split_paths
+    EvaluateTag, OptionsTag, WatcherTag, ImportTag, BannerActionTag, ContextTag
+from maryjane.helpers import get_source_dirs, has_file_overlap, split_paths, get_filename
 from watchdog.events import FileSystemEventHandler
 __author__ = 'vahid'
 
@@ -33,7 +33,8 @@ class ManifestFileEventHandler(FileSystemEventHandler):
 _context_builtins = {
     'has_file_overlap': has_file_overlap,
     'split_paths': split_paths,
-    'get_source_dirs': get_source_dirs
+    'get_source_dirs': get_source_dirs,
+    'get_filename': get_filename
 }
 
 class ManifestObserver(Observer):
@@ -77,9 +78,9 @@ class Manifest(object):
             config = yaml.load(manifest_file)
         self.tasks = {k: v for k, v in config.iteritems() if isinstance(v, TaskTag)}
         self.watching_tasks = {k: v for k, v in config.iteritems() if isinstance(v, ObservableTaskTag)}
-        if 'context' in config and isinstance(config['context'], OptionsTag):
-            self._context.update(config['context'].to_dict())
-            self._context.update(self.tasks)
+        # if 'context' in config and isinstance(config['context'], OptionsTag):
+        #     self._context.update(config['context'].to_dict())
+        self._context.update(self.tasks)
 
 
     def __getattr__(self, name):
@@ -108,6 +109,8 @@ class Manifest(object):
         yaml.add_constructor('!eval', specialize(EvaluateTag.from_yaml_node))
         yaml.add_constructor('!watcher', specialize(WatcherTag.from_yaml_node))
         yaml.add_constructor('!import', specialize(ImportTag.from_yaml_node))
+        yaml.add_constructor('!banner', specialize(BannerActionTag.from_yaml_node))
+        yaml.add_constructor('!context', specialize(ContextTag.from_yaml_node))
 
 
 
